==> tine20-allinone_2019.12.5.tar.bz2: Sales/js/Sales-lang-vi-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Sales **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Vietnamese (http://www.transifex.com/tine20/tine20/language/vi/)\nLanguage: vi\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "The number you have tried to set is already in use!"
: "Số bạn đang đặt đã tồn tại!"

, "You have to set a customer!"
: ""

, "Unknown Currency Code"
: ""

, "The Currency Code you tried to use is not valid. Please use a valid Currency Code as defined in ISO 4217."
: ""

, "Invoice is cleared already"
: ""

, "The Invoice you tried to edit is cleared already, so no editing is possible anymore!"
: ""

, "Number duplicate"
: ""

, "The number you tried to use has been taken already. Please use another one leave the field blank to take the next free number."
: ""

, "Following Invoices Found"
: ""

, "There is an invoice for the same contract after this one. Please delete the following invoice(s) before deleting this one!"
: ""

, "No Right to alter the Number"
: ""

, "You are not allowed to alter the number afterwards!"
: ""

, "Address as Billing Address in Use"
: ""

, "The Address you tried to delete is used in one or more contract(s) as Billing Address. Please assign another Billing Address to these contracts or change this one and do not delete."
: ""

, "The Invoice you tried to delete is cleared already, so deleting is not possible anymore!"
: ""

, "CLEARED"
: "ĐÃ XÓA"

, "INVOICE"
: "HÓA ĐƠN"

, "Invoice Timesheet"
: ""

, "My Products"
: "Sản phẩm của tôi"

, "Products created by me"
: ""

, "My Contracts"
: "Hợp đồng của tôi"

, "Contracts created by myself"
: "Hợp đồng tạo bởi tôi"

, "All Customers"
: ""

, "All customer records"
: ""

, "All Offers"
: ""

, "All offer records"
: ""

, "Inactive Contracts"
: ""

, "Contracts that have already been terminated"
: ""

, "Active Contracts"
: ""

, "Contracts that are still running"
: ""

, "All Suppliers"
: ""

, "All supllier records"
: ""

, "All Purchase Imvoices"
: ""

, "All purchase invoices"
: ""

, "All Products"
: ""

, "All product records"
: ""

, "All Contracts"
: ""

, "All contract records"
: ""

, "All Invoices"
: ""

, "All invoice records"
: ""

, "All Cost Centers"
: ""

, "All costcenter records"
: ""

, "All Divisions"
: ""

, "All division records"
: ""

, "All Order Confirmations"
: ""

, "All order confirmation records"
: ""

, "manage products"
: "quản lý sản phẩm"

, "add, edit and delete products"
: "thêm, xóa, sửa sản phẩm"

, "manage contracts"
: ""

, "add, edit and delete contracts"
: ""

, "manage cost centers"
: ""

, "add, edit and delete cost centers"
: ""

, "manage customers"
: ""

, "add, edit and delete customers"
: ""

, "manage suppliers"
: ""

, "add, edit and delete suppliers"
: ""

, "manage invoices"
: ""

, "add, edit and delete invoices"
: ""

, "manage divisions"
: ""

, "add, edit and delete divisions"
: ""

, "manage order confirmations"
: ""

, "add, edit and delete order confirmations"
: ""

, "manage offers"
: ""

, "add, edit and delete offers"
: ""

, "manage purchase invoices"
: ""

, "add, edit and delete purchase invoices"
: ""

, "change number of an order confirmations"
: ""

, "allow to change the number of an order confirmation on update"
: ""

, "set number of invoices"
: ""

, "allow to set the number of an invoice"
: ""

, "Ok"
: ""

, "Cancel"
: "Hủy"

, "OK"
: "OK"

, "Loading..."
: "Đang tải"

, "Euro (€)"
: ""

, "Customer, Customers"
: [
  ""

]
, "without customer"
: ""

, "Number"
: "Số"

, "Remark"
: "Đánh dấu lại"

, "Delivery Address"
: ""

, "Delivery Addresses"
: ""

, "Billing Address"
: ""

, "Billing Addresses"
: ""

, "total"
: ""

, "inclusive"
: ""

, "exceeding"
: ""

, "Create timesheet"
: ""

, "Create Reversal Invoice"
: ""

, "Copy Invoice"
: ""

, "Add New Invoice"
: ""

, "Edit Invoice \"{0}\""
: ""

, "Positions ({0})"
: ""

, "No customer assigned"
: ""

, "The selected contract doesn't have a customer assigned, yet. Add a customer to the contract with the contract edit dialog."
: ""

, "No cost center assigned"
: ""

, "The selected contract doesn't have a cost center assigned, yet. Add a cost center to the contract with the contract edit dialog."
: ""

, "Price Net"
: ""

, "Price Tax"
: ""

, "Price Gross"
: ""

, "Sales Tax (percent)"
: ""

, "Inventory Change"
: ""

, "Invoice, Invoices"
: [
  ""

]
, "Invoice Number"
: ""

, "automatically set..."
: ""

, "Date"
: ""

, "Type"
: ""

, "Description"
: "Mo tả"

, "Contract, Contracts"
: [
  "one:Hợp đồng\nother:Hợp đồng"

]
, "Miscellaneous"
: ""

, "Credit Term"
: ""

, "Cleared"
: "Đã xóa"

, "Interval Begins"
: ""

, "Interval Ends"
: ""

, "Either postalcode or postbox is required!"
: ""

, "Copy Supplier"
: ""

, "Add New Supplier"
: ""

, "Edit Supplier \"{0}\""
: ""

, "Copy address to the clipboard"
: ""

, "Supplier, Suppliers"
: [
  ""

]
, "Core Data"
: ""

, "Supplier Number"
: ""

, "Name"
: "Tên"

, "Contact Person (external)"
: ""

, "Contact Person (internal)"
: ""

, "Accounting"
: ""

, "VAT No."
: ""

, "Credit Term (days)"
: ""

, "Currency"
: ""

, "Currency Translation Rate"
: ""

, "IBAN"
: ""

, "BIC"
: ""

, "Postal Address"
: ""

, "Street"
: ""

, "Postbox"
: ""

, "Postalcode"
: ""

, "Locality"
: ""

, "Region"
: ""

, "Country"
: ""

, "Prefix"
: ""

, "Additional Prefix"
: ""

, "Web"
: ""

, "Enter description"
: ""

, "without supplier"
: ""

, "Select supplier"
: ""

, "Select invoice"
: ""

, "Select customer"
: ""

, "Customer Number"
: ""

, "without internal contact person"
: ""

, "Title"
: "Tiêu đề"

, "Add New Product"
: ""

, "Product Number"
: ""

, "GTIN"
: ""

, "Category"
: "Danh mục"

, "Manufacturer"
: "Nhà sản xuất"

, "Purchaseprice"
: ""

, "Salesprice"
: ""

, "Lifespan start"
: ""

, "Lifespan end"
: ""

, "Enter description..."
: "Nhập vào mô tả"

, "Accountable"
: ""

, "Rebilling Invoice..."
: ""

, "Rebill Invoice"
: ""

, "Merge Invoices"
: ""

, "Add New Cost Center"
: ""

, "Add New Offer"
: ""

, "Total Price"
: ""

, "Add New Order Confirmation"
: ""

, "Offer, Offers"
: [
  ""

]
, "Products"
: ""

, "Either street or postbox is required!"
: ""

, "Only numbers are allowed!"
: ""

, "Copy Customer"
: ""

, "Add New Customer"
: ""

, "Edit Customer \"{0}\""
: ""

, "Discount (%)"
: ""

, "Name shorthand"
: ""

, "Set as accountable"
: ""

, "Choose product for accountable"
: ""

, "Please use a decimal number here!"
: "Xin sử dụng 1 số thập phân tại đây!"

, "Positions"
: ""

, "Start Date"
: ""

, "End Date"
: ""

, "Lead Cost Center"
: "Trung tâm giá"

, "without external contact person"
: ""

, "Edit {0} \"{1}\""
: ""

, "Add new Billing Address"
: ""

, "Add new Delivery Address"
: ""

, "Apply postal address"
: ""

, "Number Debit"
: ""

, "Address, Addresss"
: [
  ""

]
, "Clipboard"
: ""

, "Order Confirmation, Order Confirmations"
: [
  ""

]
, "without order confirmation"
: ""

, "Copy Purchase Invoice"
: ""

, "Add New Purchase Invoice"
: ""

, "Edit Purchase Invoice \"{0}\""
: ""

, "Date of invoice"
: ""

, "Due in"
: ""

, "Due date"
: ""

, "Additional Price Gross"
: ""

, "Purchase Invoice, Purchase Invoices"
: [
  ""

]
, "Overdue date"
: ""

, "Discount until"
: ""

, "Dun date"
: ""

, "Payed at"
: ""

, "Method of payment"
: ""

, "Approver"
: ""

, "Bill Contract"
: ""

, "Billing Contract..."
: ""

, "Bill Contract \"{0} - {1}\""
: ""

, "Select the date to generate the bill for"
: ""

, "without Cost Center"
: ""

, "Product, Products"
: [
  "one:Sản phẩm\nother:Sản phẩm"

]
, "Quantity"
: ""

, "Interval"
: ""

, "Billing Point"
: ""

, "begin"
: ""

, "end"
: ""

, "Last Autobill"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Edit Attributes"
: ""

, "Attribute"
: ""

, "Value"
: ""

, "Add a New Value..."
: ""

, "Add New Division"
: ""

, "without approver"
: ""

, "Selected  {0}"
: ""

, "Export Records from these Positions"
: ""

, "without contract"
: ""

, "You do not have admin rights on Sales"
: "Bạn không có quyền quản trị trên hệ thống Kinh doanh"

, "Cost Center, Cost Centers"
: [
  ""

]
, "Due at"
: ""

, "Payment_method"
: ""

, "Sales Tax"
: ""

, "Billing Interval"
: ""

, "Invoice Item"
: ""

, "Piece"
: ""

, "Reversal Invoice"
: ""

, "Division, Divisions"
: [
  "one: Bộ phận\nother: Bộ phận"

]
, "Invoice Position, Invoice Positions"
: [
  ""

]
, "Month"
: ""

, "Unit"
: ""

, "Merge"
: ""

, "Responsible"
: "Chịu trách nhiệm"

, "Partner"
: "Đối tác"

, "Time Account"
: "Tài khoản theo thời gian"

, "Is active"
: ""

, "Auto Invoice Contract Interval"
: ""

, "Sets the biggest interval, contracts will be billed."
: ""

, "Ignore Billables Before Date"
: ""

, "Sets the date billables will be ignored before."
: ""

, "Contract Number Creation"
: "Tạo số hợp đồng"

, "Should the contract number be set manually or be auto-created?"
: "Sẽ tự động hay tự nhập"

, "automatically"
: "tự động"

, "manually"
: "tự nhập"

, "Contract Number Validation"
: "Phê chuẩn số hợp đồng"

, "The Number can be validated as text or number."
: "Số có thể được phê chuẩn khi là chữ hoặc số"

, "Text"
: "Chữ"

, "Own Currency"
: ""

, "The currency defined here is used as default currency in the customerd edit dialog."
: ""

, "Invoice Type"
: ""

, "Possible Invoice Types."
: ""

, "Reversal"
: ""

, "Credit"
: ""

, "Product Category"
: ""

, "Possible Product Categories."
: ""

, "Default"
: ""

, "Product Number Creation"
: ""

, "Should the product number be set manually or be auto-created?"
: ""

, "Product Number Validation"
: ""

, "Product Number Prefix"
: ""

, "The prefix of the product number."
: ""

, "Product Number Zero Fill"
: ""

, "Fill the number with leading zero"
: ""

, "Payment Method"
: ""

, "Possible Payment Methods."
: ""

, "Bank transfer"
: ""

, "Direct debit"
: ""

, "Cancellation"
: ""

, "Credit card"
: ""

, "EC card"
: ""

, "Paypal"
: ""

, "Assets"
: ""

, "Invoice Cleared"
: ""

, "Possible Invoice Cleared States."
: ""

, "to clear"
: ""

, "cleared"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Sales Application."
: ""

, "Invoices Module"
: ""

, "Offers Module"
: ""

, "Order Confirmations Module"
: ""

, "Suppliers Module"
: ""

, "Purchase Invoice Module"
: ""



, "Customer"
: ""

, "Invoice"
: ""

, "Contract"
: "one:Hợp đồng\nother:Hợp đồng"

, "Supplier"
: ""

, "Offer"
: ""

, "Address"
: ""

, "Order Confirmation"
: ""

, "Purchase Invoice"
: ""

, "Product"
: "one:Sản phẩm\nother:Sản phẩm"

, "Cost Center"
: ""

, "Division"
: "one: Bộ phận\nother: Bộ phận"

, "Invoice Position"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.08.8.tar.bz2: Sales/js/Sales-lang-vi-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Sales **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Vietnamese (http://www.transifex.com/tine20/tine20/language/vi/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: vi\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "CLEARED"
: "ĐÃ XÓA"

, "INVOICE"
: "HÓA ĐƠN"

, "Invoice Timesheet"
: ""

, "Customer, Customers"
: [
  ""

]
, "Core Data"
: ""

, "Accounting"
: ""

, "Miscellaneous"
: ""

, "Customer Number"
: ""

, "Name"
: "Tên"

, "Name shorthand"
: ""

, "Web"
: ""

, "Description"
: "Mo tả"

, "Contact Person (external)"
: ""

, "Contact Person (internal)"
: ""

, "VAT No."
: ""

, "Credit Term (days)"
: ""

, "Currency"
: ""

, "Currency Translation Rate"
: ""

, "Discount (%)"
: ""

, "Delivery Addresses"
: ""

, "Billing Addresses"
: ""

, "Prefix"
: ""

, "Additional Prefix"
: ""

, "Street"
: ""

, "Postalcode"
: ""

, "Locality"
: ""

, "Region"
: ""

, "Country"
: ""

, "Postbox"
: ""

, "Invoice Position, Invoice Positions"
: [
  ""

]
, "Type"
: ""

, "Title"
: "Tiêu đề"

, "Month"
: ""

, "Unit"
: ""

, "Quantity"
: ""

, "Offer, Offers"
: [
  ""

]
, "Order Confirmation, Order Confirmations"
: [
  ""

]
, "Number"
: "Số"

, "Product, Products"
: [
  "one:Sản phẩm\nother:Sản phẩm"

]
, "Contract, Contracts"
: [
  "one:Hợp đồng\nother:Hợp đồng"

]
, "Billing Interval"
: ""

, "Billing Point"
: ""

, "Start Date"
: ""

, "End Date"
: ""

, "Invoice Item"
: ""

, "Piece"
: ""

, "Purchaseprice"
: ""

, "Salesprice"
: ""

, "Category"
: "Danh mục"

, "Manufacturer"
: "Nhà sản xuất"

, "Accountable"
: ""

, "GTIN"
: ""

, "Lifespan start"
: ""

, "Lifespan end"
: ""

, "Is active"
: ""

, "Invoice, Invoices"
: [
  ""

]
, "Invoice Number"
: ""

, "Address, Addresss"
: [
  ""

]
, "Date"
: ""

, "Interval Begins"
: ""

, "Interval Ends"
: ""

, "Credit Term"
: ""

, "Cost Center, Cost Centers"
: [
  ""

]
, "Cleared"
: "Đã xóa"

, "Price Net"
: ""

, "Price Tax"
: ""

, "Price Gross"
: ""

, "Sales Tax"
: ""

, "Inventory Change"
: ""

, "Positions"
: ""

, "Reversal Invoice"
: ""

, "Supplier, Suppliers"
: [
  ""

]
, "Supplier Number"
: ""

, "Division, Divisions"
: [
  "one: Bộ phận\nother: Bộ phận"

]
, "Number Debit"
: ""

, "Products"
: ""

, "Billing Address"
: ""

, "Lead Cost Center"
: "Trung tâm giá"

, "Merge"
: ""

, "Responsible"
: "Chịu trách nhiệm"

, "Partner"
: "Đối tác"

, "Time Account"
: "Tài khoản theo thời gian"

, "Remark"
: "Đánh dấu lại"

, "Purchase Invoice, Purchase Invoices"
: [
  ""

]
, "Approver"
: ""

, "Date of invoice"
: ""

, "Due in"
: ""

, "Due at"
: ""

, "Payed at"
: ""

, "Payment_method"
: ""

, "Discount until"
: ""

, "Additional Price Gross"
: ""

, "Total Price"
: ""

, "without customer"
: ""

, "Export Records from these Positions"
: ""

, "Either postalcode or postbox is required!"
: ""

, "Copy Supplier"
: ""

, "Add New Supplier"
: ""

, "Edit Supplier \"{0}\""
: ""

, "Copy address to the clipboard"
: ""

, "IBAN"
: ""

, "BIC"
: ""

, "Postal Address"
: ""

, "Enter description"
: ""

, "Cancel"
: "Hủy"

, "Ok"
: ""

, "Select customer"
: ""

, "Bill Contract"
: ""

, "Billing Contract..."
: ""

, "Bill Contract \"{0} - {1}\""
: ""

, "Select the date to generate the bill for"
: ""

, "total"
: ""

, "inclusive"
: ""

, "exceeding"
: ""

, "Create timesheet"
: ""

, "Create Reversal Invoice"
: ""

, "Copy Invoice"
: ""

, "Add New Invoice"
: ""

, "Edit Invoice \"{0}\""
: ""

, "Positions ({0})"
: ""

, "No customer assigned"
: ""

, "The selected contract doesn't have a customer assigned, yet. Add a customer to the contract with the contract edit dialog."
: ""

, "No cost center assigned"
: ""

, "The selected contract doesn't have a cost center assigned, yet. Add a cost center to the contract with the contract edit dialog."
: ""

, "Sales Tax (percent)"
: ""

, "automatically set..."
: ""

, "OK"
: "OK"

, "Loading..."
: "Đang tải"

, "Euro (€)"
: ""

, "Set as accountable"
: ""

, "Choose product for accountable"
: ""

, "Please use a decimal number here!"
: "Xin sử dụng 1 số thập phân tại đây!"

, "Enter description..."
: "Nhập vào mô tả"

, "Add New Product"
: ""

, "Product Number"
: ""

, "Select supplier"
: ""

, "Add New Cost Center"
: ""

, "Select invoice"
: ""

, "Either street or postbox is required!"
: ""

, "Only numbers are allowed!"
: ""

, "Copy Customer"
: ""

, "Add New Customer"
: ""

, "Edit Customer \"{0}\""
: ""

, "without external contact person"
: ""

, "without approver"
: ""

, "without supplier"
: ""

, "Copy Purchase Invoice"
: ""

, "Add New Purchase Invoice"
: ""

, "Edit Purchase Invoice \"{0}\""
: ""

, "Due date"
: ""

, "Overdue date"
: ""

, "Dun date"
: ""

, "Method of payment"
: ""

, "without internal contact person"
: ""

, "Delivery Address"
: ""

, "Edit {0} \"{1}\""
: ""

, "Add new Billing Address"
: ""

, "Add new Delivery Address"
: ""

, "Apply postal address"
: ""

, "Add New Offer"
: ""

, "Add New Order Confirmation"
: ""

, "Interval"
: ""

, "begin"
: ""

, "end"
: ""

, "Last Autobill"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Edit Attributes"
: ""

, "Attribute"
: ""

, "Value"
: ""

, "Add a New Value..."
: ""

, "Clipboard"
: ""

, "Add New Division"
: ""

, "without contract"
: ""

, "without order confirmation"
: ""

, "Rebilling Invoice..."
: ""

, "Rebill Invoice"
: ""

, "Merge Invoices"
: ""

, "without Cost Center"
: ""

, "Auto Invoice Contract Interval"
: ""

, "Sets the biggest interval, contracts will be billed."
: ""

, "Ignore Billables Before Date"
: ""

, "Sets the date billables will be ignored before."
: ""

, "Contract Number Creation"
: "Tạo số hợp đồng"

, "Should the contract number be set manually or be auto-created?"
: "Sẽ tự động hay tự nhập"

, "automatically"
: "tự động"

, "manually"
: "tự nhập"

, "Contract Number Validation"
: "Phê chuẩn số hợp đồng"

, "The Number can be validated as text or number."
: "Số có thể được phê chuẩn khi là chữ hoặc số"

, "Text"
: "Chữ"

, "Own Currency"
: ""

, "The currency defined here is used as default currency in the customerd edit dialog."
: ""

, "Invoice Type"
: ""

, "Possible Invoice Types."
: ""

, "Reversal"
: ""

, "Credit"
: ""

, "Product Category"
: ""

, "Possible Product Categories."
: ""

, "Default"
: ""

, "Product Number Creation"
: ""

, "Should the product number be set manually or be auto-created?"
: ""

, "Product Number Validation"
: ""

, "Product Number Prefix"
: ""

, "The prefix of the product number."
: ""

, "Product Number Zero Fill"
: ""

, "Fill the number with leading zero"
: ""

, "Payment Method"
: ""

, "Possible Payment Methods."
: ""

, "Bank transfer"
: ""

, "Direct debit"
: ""

, "Cancellation"
: ""

, "Credit card"
: ""

, "EC card"
: ""

, "Paypal"
: ""

, "Invoice Cleared"
: ""

, "Possible Invoice Cleared States."
: ""

, "to clear"
: ""

, "cleared"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Sales Application."
: ""

, "Invoices Module"
: ""

, "Offers Module"
: ""

, "Order Confirmations Module"
: ""

, "Suppliers Module"
: ""

, "Purchase Invoice Module"
: ""

, "manage products"
: "quản lý sản phẩm"

, "add, edit and delete products"
: "thêm, xóa, sửa sản phẩm"

, "manage contracts"
: ""

, "add, edit and delete contracts"
: ""

, "manage cost centers"
: ""

, "add, edit and delete cost centers"
: ""

, "manage customers"
: ""

, "add, edit and delete customers"
: ""

, "manage suppliers"
: ""

, "add, edit and delete suppliers"
: ""

, "manage invoices"
: ""

, "add, edit and delete invoices"
: ""

, "manage divisions"
: ""

, "add, edit and delete divisions"
: ""

, "manage order confirmations"
: ""

, "add, edit and delete order confirmations"
: ""

, "manage offers"
: ""

, "add, edit and delete offers"
: ""

, "manage purchase invoices"
: ""

, "add, edit and delete purchase invoices"
: ""

, "change number of an order confirmations"
: ""

, "allow to change the number of an order confirmation on update"
: ""

, "set number of invoices"
: ""

, "allow to set the number of an invoice"
: ""

, "No Right to alter the Number"
: ""

, "You are not allowed to alter the number afterwards!"
: ""

, "Address as Billing Address in Use"
: ""

, "The Address you tried to delete is used in one or more contract(s) as Billing Address. Please assign another Billing Address to these contracts or change this one and do not delete."
: ""

, "Number duplicate"
: ""

, "The number you tried to use has been taken already. Please use another one leave the field blank to take the next free number."
: ""

, "Following Invoices Found"
: ""

, "There is an invoice for the same contract after this one. Please delete the following invoice(s) before deleting this one!"
: ""

, "Invoice is cleared already"
: ""

, "The Invoice you tried to edit is cleared already, so no editing is possible anymore!"
: ""

, "The Invoice you tried to delete is cleared already, so deleting is not possible anymore!"
: ""

, "Unknown Currency Code"
: ""

, "The Currency Code you tried to use is not valid. Please use a valid Currency Code as defined in ISO 4217."
: ""

, "You do not have admin rights on Sales"
: "Bạn không có quyền quản trị trên hệ thống Kinh doanh"

, "The number you have tried to set is already in use!"
: "Số bạn đang đặt đã tồn tại!"

, "My Products"
: "Sản phẩm của tôi"

, "Products created by me"
: ""

, "My Contracts"
: "Hợp đồng của tôi"

, "Contracts created by myself"
: "Hợp đồng tạo bởi tôi"

, "All Customers"
: ""

, "All customer records"
: ""

, "All Offers"
: ""

, "All offer records"
: ""

, "Inactive Contracts"
: ""

, "Contracts that have already been terminated"
: ""

, "Active Contracts"
: ""

, "Contracts that are still running"
: ""

, "Products created by myself"
: "Sản phẩm tạo bởi tôi"

, "Status"
: "Trạng thái"

, "Cleared In"
: ""

, "All Suppliers"
: ""

, "All supllier records"
: ""

, "All Purchase Imvoices"
: ""

, "All purchase invoices"
: ""

, "All Products"
: ""

, "All product records"
: ""

, "All Contracts"
: ""

, "All contract records"
: ""

, "All Invoices"
: ""

, "All invoice records"
: ""

, "All Cost Centers"
: ""

, "All costcenter records"
: ""

, "All Divisions"
: ""

, "All division records"
: ""

, "All Order Confirmations"
: ""

, "All order confirmation records"
: ""

, "You have to set a customer!"
: ""

, "Taxes (VAT)"
: ""

, "VAT ID"
: ""

, "Selected  {0}"
: ""

, "Add New Billing Address"
: ""

, "Add New Delivery Address"
: ""

, "Manage Products"
: ""

, "Add, edit and delete products."
: ""

, "Manage Contracts"
: ""

, "Add, edit and delete contracts."
: ""

, "Manage Cost Centers"
: ""

, "Add, edit and delete cost centers."
: ""

, "Manage Customers"
: ""

, "Add, edit and delete customers."
: ""

, "Manage Suppliers"
: ""

, "Add, edit and delete suppliers."
: ""

, "Add, edit and delete invoices."
: ""

, "Manage Divisions"
: ""

, "Add, edit and delete divisions."
: ""

, "Manage Order Confirmations"
: ""

, "Add, edit and delete order confirmations."
: ""

, "Manage Offers"
: ""

, "Add, edit and delete offers."
: ""

, "Manage Purchase Invoices"
: ""

, "Add, edit and delete purchase invoices."
: ""

, "Change number of an order confirmations"
: ""

, "Allow changing the number of an order confirmation during the update."
: ""

, "Set number of invoices"
: ""

, "Allow to set the number of an invoice."
: ""

, "Customer"
: ""

, "Invoice Position"
: ""

, "Offer"
: ""

, "Order Confirmation"
: ""

, "Product"
: "one:Sản phẩm\nother:Sản phẩm"

, "Contract"
: "one:Hợp đồng\nother:Hợp đồng"

, "Invoice"
: ""

, "Address"
: ""

, "Cost Center"
: ""

, "Supplier"
: ""

, "Division"
: "one: Bộ phận\nother: Bộ phận"

, "Purchase Invoice"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
